@@ -1,7 +1,7 @@
 package Monitoring::Icinga2::Client::Simple;
-$Monitoring::Icinga2::Client::Simple::VERSION = '0.001000_03'; # TRIAL
+$Monitoring::Icinga2::Client::Simple::VERSION = '0.001000_04'; # TRIAL
 
-$Monitoring::Icinga2::Client::Simple::VERSION = '0.00100003';use strict;
+$Monitoring::Icinga2::Client::Simple::VERSION = '0.00100004';use strict;
 use warnings;
 use 5.010_001;
 use Monitoring::Icinga2::Client::REST 2;
@@ -115,16 +115,16 @@ sub send_custom_notification {
     );
 }
 
-sub notifications {
-    my ($self, $state, %args) = @_;
-    defined $state or croak( '$state is required to be a boolean value' );
+sub set_notifications {
+    my ($self, %args) = @_;
+    _checkargs(\%args, qw/ state /);
     _checkargs_any(\%args, qw/ host service /);
     my $uri_object = $args{service} ? 'services' : 'hosts';
 
     return $self->_verbose_request('POST',
         "/objects/$uri_object/",
         {
-            attrs => { enable_notifications => !!$state },
+            attrs => { enable_notifications => !!$args{state} },
             filter => _create_filter( \%args ),
         }
     );
@@ -175,7 +175,7 @@ sub query_app_attrs {
     }
 }
 
-sub global_notifications {
+sub set_global_notifications {
     my ($self, $state) = @_;
     $self->set_app_attrs( notifications => $state );
 }
@@ -203,7 +203,7 @@ sub _checkargs {
     my $args = shift;
 
     all { defined $args->{$_} } @_ or croak(
-        sprintf "Missing or undefined argument `%s' to %s()",
+        sprintf "missing or undefined argument `%s' to %s()",
         ( first { not defined $args->{$_} } @_ ),
         (caller(1))[3]
     );
@@ -215,7 +215,7 @@ sub _checkargs_any {
    my $args = shift;
 
    any { defined $args->{$_} } grep { exists $args->{$_} } @_ or croak(
-       sprintf "Need at least one argument of: %s to %s()",
+       sprintf "need at least one argument of: %s to %s()",
        join(',', @_), (caller(1))[3]
    );
 }
@@ -253,7 +253,7 @@ Monitoring::Icinga2::Client::Simple
 
 =head1 VERSION
 
-version 0.001000_03
+version 0.001000_04
 
 =head1 DESCRIPTION
 
@@ -460,14 +460,15 @@ additionally one of C<host> and C<service> must be set.
 Note that for this call C<host> and C<service> are mutually exclusive. If both
 are present, C<host> wins.
 
-=head2 notifications
+=head2 set_notifications
 
-    $ia->notifications( 0, host => 'web-1' );
+    $ia->set_notifications( state => 0, host => 'web-1' );
 
-Enable or disable notifications for a host or service. C<$state> is a boolean
-that gives the desired state; C<host> or C<service> specifiy the object.
+Enable or disable notifications for a host or service. C<state> is a boolean
+specifying whether to switch notifications on or off; C<host> or C<service>
+specifiy the object.
 
-Use L</global_notifications> to toggle notifications application-wide.
+Use L</set_global_notifications> to toggle notifications application-wide!
 
 =head2 query_app_attrs
 
@@ -530,9 +531,9 @@ Set application attributes passed as hash-style arguments. Of the ones returned
 by L</query_app_attrs>, only the booleans are settable; their names don't
 include the `C<enable_>' prefix.
 
-=head2 global_notifications
+=head2 set_global_notifications
 
-    $ia->global_notifications( 0 );
+    $ia->set_global_notifications( 0 );
 
 Convenience method to enable/disable global notifications, equivalent to
 C<set_app_attrs( notifications =E<gt> $state)>. The only mandatory argument is
